@@ -5,6 +5,8 @@ OC.L10N.register(
     "New note" : "Ny note",
     "Note is currently saving. Leaving the page will delete all changes!" : "Note er i færd med at blive gemt. Forladelde af siden vil slette alle ændringer!",
     "_%n word_::_%n words_" : ["%n ord","%n dage"],
-    "Delete note" : "Slet note"
+    "Delete note" : "Slet note",
+    "Favorite" : "Foretrukken",
+    "No notes found" : "Ingen noter fundet"
 },
 "nplurals=2; plural=(n != 1);");
