@@ -5,6 +5,8 @@ OC.L10N.register(
     "New note" : "Νέα σημείωση",
     "Note is currently saving. Leaving the page will delete all changes!" : "Σημείωση προς το παρόν είναι η αποταμίευση. Αφήστε τη σελίδα θα διαγράψει όλες τις αλλαγές!",
     "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
-    "Delete note" : "Διαγραφή σημείωσης"
+    "Delete note" : "Διαγραφή σημείωσης",
+    "Favorite" : "Αγαπημένο",
+    "No notes found" : "Δεν βρέθηκαν σημειώσεις"
 },
 "nplurals=2; plural=(n != 1);");
