@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "New note" : "Nouvelle note",
-    "Note is currently saving. Leaving the page will delete all changes!" : "Note en cours de sauvegarde. Quitter la page supprimera tous les changements !",
+    "Note is currently saving. Leaving the page will delete all changes!" : "Note en cours d'enregistrement. Quitter la page perdra toutes les modifications !",
     "_%n word_::_%n words_" : ["%n mot","%n mots"],
     "Delete note" : "Supprimer la note",
     "Favorite" : "Favoris",
