@@ -6,6 +6,7 @@ OC.L10N.register(
     "Note is currently saving. Leaving the page will delete all changes!" : "ノートを保存しています。このページから移動する場合は全ての変更が削除されます！",
     "_%n word_::_%n words_" : ["%n 単語"],
     "Delete note" : "ノートを削除",
-    "Favorite" : "お気に入り"
+    "Favorite" : "お気に入り",
+    "No notes found" : "ノートがありません"
 },
 "nplurals=1; plural=0;");
