@@ -4,9 +4,9 @@ OC.L10N.register(
     "Notes" : "Notatki",
     "New note" : "Nowa notatka",
     "Note is currently saving. Leaving the page will delete all changes!" : "Notatka jest obecnie zapisywana. Opuszczenie strony spowoduje usunięciem wszystkich danych!",
-    "_%n word_::_%n words_" : ["%n słowo","%n słowa","%n słów"],
+    "_%n word_::_%n words_" : ["%n słowo","%n słowa","%n słów","%n słów"],
     "Delete note" : "Usuń notatkę",
     "Favorite" : "Ulubione",
     "No notes found" : "Nie znaleziono notatek"
 },
-"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
+"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
