@@ -3,9 +3,9 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "New note" : "Nova nota",
-    "Note is currently saving. Leaving the page will delete all changes!" : "A nota está sendo salva. Sair da página irá apagar todas as mudanças!",
+    "Note is currently saving. Leaving the page will delete all changes!" : "A anotação está sendo salva. Sair da página irá apagar todas as mudanças!",
     "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
-    "Delete note" : "Eliminar nota",
+    "Delete note" : "Excluir anotação",
     "Favorite" : "Favorito",
     "No notes found" : "Nenhuma nota encontrada"
 },
