@@ -5,6 +5,8 @@ OC.L10N.register(
     "New note" : "Notă nouă",
     "Note is currently saving. Leaving the page will delete all changes!" : "Nota este în curs de salvare. Părăsirea paginii va determina ștergerea tuturor modificărilor!",
     "_%n word_::_%n words_" : ["%n cuvânt","%n cuvinte","%n cuvinte"],
-    "Delete note" : "Şterge nota"
+    "Delete note" : "Şterge nota",
+    "Favorite" : "Favorite",
+    "No notes found" : "Nu s-au găsit note"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
