@@ -5,6 +5,8 @@ OC.L10N.register(
     "New note" : "Novo sporočilce",
     "Note is currently saving. Leaving the page will delete all changes!" : "Sporočilce se še shranjuje. Če zapustite stran, bodo spremembe izgubljene!",
     "_%n word_::_%n words_" : ["%n beseda","%n besedi","%n besede","%n besed"],
-    "Delete note" : "Izbriši sporočilce"
+    "Delete note" : "Izbriši sporočilce",
+    "Favorite" : "Priljubljene",
+    "No notes found" : "Ne najdem opomb"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
