@@ -6,6 +6,7 @@ OC.L10N.register(
     "Note is currently saving. Leaving the page will delete all changes!" : "Not şu anda kaydediliyor. Sayfadan ayrılırsanız yapılan değişiklikler silinir!",
     "_%n word_::_%n words_" : ["%n sözcük","%n sözcük"],
     "Delete note" : "Notu sil",
-    "Favorite" : "Sık kullanılan"
+    "Favorite" : "Sık kullanılan",
+    "No notes found" : "Herhangi bir not bulunamadı"
 },
 "nplurals=2; plural=(n > 1);");
