@@ -13,14 +13,12 @@ script('notes', [
     'vendor/angular-route/angular-route',
     'vendor/restangular/dist/restangular',
     'vendor/underscore/underscore',
-    'vendor/prism/prism',
-    'vendor/mdEdit/mdedit.min',
+    'vendor/simplemde/dist/simplemde.min',
     'public/app.min'
 ]);
 
 style('notes', [
-    '../js/vendor/mdEdit/mdedit',
-    '../js/vendor/mdEdit/prism',
+    '../js/vendor/simplemde/dist/simplemde.min',
     'vendor/bootstrap/tooltip',
     'notes'
 ]);
@@ -42,10 +40,12 @@ style('notes', [
                 </span>
             </li>
             <!-- new note button -->
-            <li id="note-add" ng-click="create()"
+            <div id="note-add">            
+                <button class="icon-add app-content-list-button ng-binding" id="new-note-button" type="button" name="button" ng-click="create()"
                 oc-click-focus="{ selector: '#app-content textarea' }">
-                <a href='#'>+ <span><?php p($l->t('New note')); ?></span></a>
-            </li>
+                    <?php p($l->t('New note')); ?> 
+                </button>
+            </div>
             <!-- notes list -->
             <li ng-repeat="note in filteredNotes = (notes| and:search | orderBy:['-favorite','-modified'])"
                 ng-class="{ active: note.id == route.noteId }">
